@@ -22,8 +22,6 @@
 
 struct sms_data {
 	struct qmi_service *wms;
-	uint16_t major;
-	uint16_t minor;
 	struct qmi_wms_read_msg_id rd_msg_id;
 	struct qmi_wms_result_msg_list *msg_list;
 	uint32_t rd_msg_num;
@@ -263,16 +261,11 @@ static void qmi_bearer_query(struct ofono_sms *sms,
 
 	DBG("");
 
-	if (data->major < 1 || (data->major == 1 && data->minor < 2))
-		goto error;
-
 	if (qmi_service_send(data->wms, QMI_WMS_GET_DOMAIN_PREF, NULL,
 					get_domain_pref_cb, cbd, l_free) > 0)
 		return;
 
-error:
 	CALLBACK_WITH_FAILURE(cb, -1, cbd->data);
-
 	l_free(cbd);
 }
 
@@ -301,9 +294,6 @@ static void qmi_bearer_set(struct ofono_sms *sms, int bearer,
 
 	DBG("bearer %d", bearer);
 
-	if (data->major < 1 || (data->major == 1 && data->minor < 2))
-		goto error;
-
 	domain = bearer_to_domain(bearer);
 
 	param = qmi_param_new_uint8(QMI_WMS_PARAM_DOMAIN, domain);
@@ -314,7 +304,6 @@ static void qmi_bearer_set(struct ofono_sms *sms, int bearer,
 
 	qmi_param_free(param);
 
-error:
 	CALLBACK_WITH_FAILURE(cb, cbd->data);
 	l_free(cbd);
 }
@@ -353,7 +342,7 @@ static void delete_msg(struct ofono_sms *sms, uint8_t tag)
 {
 	struct sms_data *data = ofono_sms_get_data(sms);
 	struct qmi_param *param;
-	qmi_result_func_t func = NULL;
+	qmi_service_result_func_t func = NULL;
 
 	DBG("");
 
@@ -725,58 +714,32 @@ static void set_event_cb(struct qmi_result *result, void *user_data)
 	ofono_sms_register(sms);
 }
 
-static void create_wms_cb(struct qmi_service *service, void *user_data)
-{
-	struct ofono_sms *sms = user_data;
-	struct sms_data *data = ofono_sms_get_data(sms);
-	struct qmi_param *param;
-
-	DBG("");
-
-	if (!service) {
-		ofono_error("Failed to request WMS service");
-		ofono_sms_remove(sms);
-		return;
-	}
-
-	if (!qmi_service_get_version(service, &data->major, &data->minor)) {
-		ofono_error("Failed to get WMS service version");
-		ofono_sms_remove(sms);
-		return;
-	}
-
-	data->wms = service;
-
-	memset(&data->rd_msg_id, 0, sizeof(data->rd_msg_id));
-	data->msg_mode = QMI_WMS_MESSAGE_MODE_GSMWCDMA;
-
-	qmi_service_register(data->wms, QMI_WMS_EVENT,
-					event_notify, sms, NULL);
-
-	param = qmi_param_new_uint8(QMI_WMS_PARAM_NEW_MSG_REPORT, 0x01);
-
-	if (qmi_service_send(data->wms, QMI_WMS_SET_EVENT, param,
-					set_event_cb, sms, NULL) > 0)
-		return;
-
-	ofono_sms_register(sms);
-}
-
 static int qmi_sms_probe(struct ofono_sms *sms,
 				unsigned int vendor, void *user_data)
 {
-	struct qmi_device *device = user_data;
+	struct qmi_service *wms = user_data;
+	struct qmi_param *param;
 	struct sms_data *data;
 
 	DBG("");
 
+	param = qmi_param_new_uint8(QMI_WMS_PARAM_NEW_MSG_REPORT, 0x01);
+
+	if (!qmi_service_send(wms, QMI_WMS_SET_EVENT, param,
+					set_event_cb, sms, NULL)) {
+		qmi_param_free(param);
+		qmi_service_free(wms);
+		return -EIO;
+	}
+
 	data = l_new(struct sms_data, 1);
+	data->wms = wms;
+	memset(&data->rd_msg_id, 0, sizeof(data->rd_msg_id));
+	data->msg_mode = QMI_WMS_MESSAGE_MODE_GSMWCDMA;
+	qmi_service_register(data->wms, QMI_WMS_EVENT, event_notify, sms, NULL);
 
 	ofono_sms_set_data(sms, data);
 
-	qmi_service_create_shared(device, QMI_SERVICE_WMS, create_wms_cb, sms,
-					NULL);
-
 	return 0;
 }
 
@@ -788,11 +751,10 @@ static void qmi_sms_remove(struct ofono_sms *sms)
 
 	ofono_sms_set_data(sms, NULL);
 
-	qmi_service_free(data->wms);
-
 	if (data->msg_list)
 		l_free(data->msg_list);
 
+	qmi_service_free(data->wms);
 	l_free(data);
 }
 
