@@ -1,24 +1,10 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies)
+ * Copyright (C) 2011  Intel Corporation
+ * Copyright (C) 2011  ProFUSION embedded systems
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2010  Nokia Corporation and/or its subsidiary(-ies).
- *  Copyright (C) 2011  Intel Corporation. All rights reserved.
- *  Copyright (C) 2011  ProFUSION embedded systems.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -39,8 +25,6 @@
 #define DBUS_TYPE_UNIX_FD -1
 #endif
 
-static GSList *g_drivers = NULL;
-
 struct ofono_location_reporting {
 	DBusMessage *pending;
 	const struct ofono_location_reporting_driver *driver;
@@ -102,7 +86,7 @@ static void client_remove(struct ofono_location_reporting *lr)
 		lr->disconnect_watch = 0;
 	}
 
-	g_free(lr->client_owner);
+	l_free(lr->client_owner);
 }
 
 static void signal_enabled(const struct ofono_location_reporting *lr)
@@ -180,7 +164,7 @@ static void location_reporting_enable_cb(const struct ofono_error *error,
 	}
 
 	lr->enabled = TRUE;
-	lr->client_owner = g_strdup(dbus_message_get_sender(lr->pending));
+	lr->client_owner = l_strdup(dbus_message_get_sender(lr->pending));
 	lr->disconnect_watch = g_dbus_add_disconnect_watch(conn,
 				lr->client_owner, client_exited, lr, NULL);
 
@@ -257,30 +241,6 @@ static const GDBusSignalTable location_reporting_signals[] = {
 	{ }
 };
 
-int ofono_location_reporting_driver_register(
-				const struct ofono_location_reporting_driver *d)
-{
-	DBG("driver: %p, name: %s", d, d->name);
-
-	if (d == NULL || d->probe == NULL)
-		return -EINVAL;
-
-	g_drivers = g_slist_prepend(g_drivers, (void *) d);
-
-	return 0;
-}
-
-void ofono_location_reporting_driver_unregister(
-				const struct ofono_location_reporting_driver *d)
-{
-	DBG("driver: %p, name: %s", d, d->name);
-
-	if (d == NULL)
-		return;
-
-	g_drivers = g_slist_remove(g_drivers, (void *) d);
-}
-
 struct ofono_modem *ofono_location_reporting_get_modem(
 					struct ofono_location_reporting *lr)
 {
@@ -314,44 +274,8 @@ static void location_reporting_remove(struct ofono_atom *atom)
 	g_free(lr);
 }
 
-struct ofono_location_reporting *ofono_location_reporting_create(
-						struct ofono_modem *modem,
-						unsigned int vendor,
-						const char *driver, void *data)
-{
-	struct ofono_location_reporting *lr;
-	GSList *l;
-
-	if (driver == NULL)
-		return NULL;
-
-	/* Only D-Bus >= 1.3 supports fd-passing */
-	if (DBUS_TYPE_UNIX_FD == -1)
-		return NULL;
-
-	lr = g_try_new0(struct ofono_location_reporting, 1);
-	if (lr == NULL)
-		return NULL;
-
-	lr->atom = __ofono_modem_add_atom(modem,
-					OFONO_ATOM_TYPE_LOCATION_REPORTING,
-					location_reporting_remove, lr);
-
-	for (l = g_drivers; l; l = l->next) {
-		const struct ofono_location_reporting_driver *drv = l->data;
-
-		if (g_strcmp0(drv->name, driver) != 0)
-			continue;
-
-		if (drv->probe(lr, vendor, data) < 0)
-			continue;
-
-		lr->driver = drv;
-		break;
-	}
-
-	return lr;
-}
+OFONO_DEFINE_ATOM_CREATE(location_reporting,
+				OFONO_ATOM_TYPE_LOCATION_REPORTING)
 
 void ofono_location_reporting_register(struct ofono_location_reporting *lr)
 {
